function [cwtSignal, cwtSignal_avg] = CWTscalogram(signal,Fs,fmin,fmax,...
                                      signalname,plotting)
% CWTscalogram Time-frequency and average frequency calculation
%   cwtSignal = CWTscalogram(signal,Fs,fmin,fmax,signalname,plotting)
%   returns a struct with data from CWT analysis, such as coefficients,
%   scales, corresonding frequencies, etc. CWT is performed on signal, with 
%   sampling frequency Fs, in the frequency band specified by fmin and
%   fmax. signalname is a string used in the figure when plotting. plotting
%   is a string where value '1' plots 3-D CWT scalogram and average CWT
%   scaleogram, and '2' only the latter. Other values return no plot.
%
%   [cwtSignal, cwtSignal_avg] = CWTscalogram(signal,Fs,fmin,fmax,...
%   signalname,plotting) returns vector with average CWT coefficients
%

%   Created by Mathias Falk, last modified 16/05/16


    % CWT 
    DT = 1/Fs;
    t = 0:DT:(numel(signal)*DT)-DT;
    f0 = 5/(2*pi);
    %f0 = 2*DT; % = 0.5fs
    %f0 = 0.25;

    scales = helperCWTTimeFreqVector(fmin,fmax,f0,DT,32);
    cwtSignal = cwtft({signal,DT},'wavelet','morl','scales',scales);
    cwtSignal.t = t;
    
    cwtSignal_avg = mean(abs(cwtSignal.cfs),2); % average CWT
    
    
    % Plotting
    if strcmp(plotting,'1') == 1
    % 3-D scalogram CWT
    figure
    helperCWTTimeFreqPlot(cwtSignal.cfs,t,cwtSignal.frequencies,...
    'surf',['CWT scalogram of ' signalname],'Time [seconds]','Frequency [Hz]')
    set(gca,'yscale','log');
    end
    %set(gca,'FontSize',14)
    
    if strcmp(plotting,'1') == 1 || strcmp(plotting,'2')
    % Avg scalogram CWT
    figure
    semilogx(cwtSignal.frequencies,cwtSignal_avg)
    % plot(cwtSignal.frequencies,cwtSignal_avg)
    xlabel('Frequency [Hz]'); ylabel('Power [AU]')
    title(['Average CWT of ' signalname])
    end
    %set(gca,'FontSize',14)
end


