function [HRVsignal, HRVinfo] = HRV(ECG_exc)
% HRV Heart rate variability (HRV) signal extraction of ECG input signal.
%   HRVsignal = HRV(X) returns HRV signal for the N by 1 ECG vector X.
%   Row 1 of HRVsignal is N-1 location values for R peak in QRS complex
%   of ECG sginal. Row 2 is N-1 RR interval corresponding to distance
%   between successive R peaks.
%
%   [HRVsignal, HRVinfo] = HRV(X) returns all N locations for detected
%   R peaks in first row and corresponding R peak value in the second 
%   row.
%

%   Created by Mathias Falk, last modified 16/05/16
   
    
    ECG_exc = ECG_exc - mean(ECG_exc);
    
    % Peak detection
    [pks,loc] = findpeaks(ECG_exc,'MinPeakProminence',1e-4,...
                'MinPeakDistance',200);
     
    
    % HRV calculation
    HRV1 = [];
    for i=1:length(loc)-1
        RR = loc(i+1)-loc(i);
        HRV1 = [HRV1 RR];
    end
    
    HRVsignal = [loc(1:end-1);HRV1];
    HRVinfo = [loc;pks];
end
