% classifications Classification with different classifiers
%   Run classification using classify function, with predefined 
%   combinations of parameter tunings. Select input parameters; features,
%   class vector, number of features for classification, k-fold cross
%   validation number, and iterations of kfold. Output are perfomance
%   metrics; correct rate, sensitivity and specificity, all ordered in
%   vectors by descending order, with index linking to which classifier,
%   seen in the list here in the script. Also bar plot of total weights per
%   feature from all feature selection runs in training each classifier. 
%



% Created by Mathias Falk, last modified 04/09/16


% Specify classification features, classes and validation
featureX = scoresPCA;% featureHyperSub; % 
NumFeat = 0; 
classY = classNum2;
kfold = 6;
kfolditer = 5;




% Classification classifier parameter combinations
optionMatrix = {'discr','linear',0,0;                   % 1
                'discr', 'diagQuadratic',0,0;           % 2
                'dtree',4,0,0;                          % 3
                'dtree',20,0,0;                         % 4
                'dtree',100,0,0;                        % 5
                'knn','euclidean',1,'equal';            % 6
                'knn','euclidean',1,'squaredinverse';   % 7
                'knn','euclidean',5,'equal';            % 8
                'knn','euclidean',5,'squaredinverse';   % 9
                'knn','euclidean',12,'equal';           % 10
                'knn','euclidean',12,'squaredinverse';  % 11
                'knn','cosine',1,'equal';               % 12
                'knn','cosine',1,'squaredinverse';      % 13
                'knn','cosine',5,'equal';               % 14
                'knn','cosine',5,'squaredinverse';      % 15
                'knn','cosine',9,'equal';               % 16
                'knn','cosine',9,'squaredinverse';      % 17
                'knn','minkowski',1,'equal';            % 18
                'knn','minkowski',1,'squaredinverse';   % 19
                'knn','minkowski',5,'equal';            % 20
                'knn','minkowski',5,'squaredinverse';   % 21
                'knn','minkowski',9,'equal';            % 22
                'knn','minkowski',9,'squaredinverse';   % 23
                'svm','linear','auto',1;                % 24
                'svm','linear','auto',10;               % 25
                'svm','linear',1,1;                     % 26
                'svm','linear',1,10;                    % 27
                'svm','linear',5,1;                     % 28
                'svm','linear',5,10;                    % 29
                'svm','gaussian','auto',1;              % 30
                'svm','gaussian','auto',10;             % 31
                'svm','gaussian',1,1;                   % 32
                'svm','gaussian',1,10;                  % 33
                'svm','gaussian',5,1;                   % 34
                'svm','gaussian',5,10;                  % 35
                'svm','polynomial','auto',1;            % 36
                'svm','polynomial','auto',10;           % 37
                'svm','polynomial',1,1;                 % 38
                'svm','polynomial',1,10;                % 39
                'svm','polynomial',5,1;                 % 40
                'svm','polynomial',5,10;                % 41
                };  

            

            
cpVector = [];
cpCorrectVector = [];
cpSensVector = [];
cpSpecVector = [];
fscoring = 0;
for i=1:length(optionMatrix)
    [cp,fscore] = classify(featureX,classY,kfold,kfolditer,...
               optionMatrix{i,1},optionMatrix{i,2},optionMatrix{i,3},...
               optionMatrix{i,4},NumFeat,30);
     cpVector = [cpVector cp];
     cpCorrectVector = [cpCorrectVector cp.CorrectRate];
     cpSensVector = [cpSensVector cp.Sensitivity];
     cpSpecVector = [cpSpecVector cp.Specificity];
     fscoring = fscoring + fscore;
end
            

% Classification performance metrics vectors, and index of the classifier
[cr,cridx] = sort(cpCorrectVector,'descend');
[se,seidx] = sort(cpSensVector,'descend');
[sp,spidx] = sort(cpSpecVector,'descend');


% Feature selection analysis
[sc,scidx]=sort(fscoring,'descend');
bar(fscoring)
xlabel('Feature [number]'); ylabel('Total weight value')
set(gca,'FontSize',14)


% Feature scores
hrvscore = []; % for HRV 5 first bands
for i=1:6
    hrvscore = [hrvscore sum(fscoring(1,i:6:30))];
end

abpscore = []; % for ABP all 6 bands
for i=1:6
    abpscore = [abpscore sum(fscoring300(1,i:37:36+36))];
end


