% dataProc Data processing
%   Perform HRV extraction from ECG, and resampling and filtering for all 
%   three signals in patient struct, first obtained from running 
%   dataextXX.m for each patient. Then runs CWT analysis for all signals
%   and stores new signals (HRV and downsampled ABP and LDF) and CWT
%   signals
%

%   Created by Mathias Falk, last modified 10/06/16


%% HRV 
for i=1:10  % length(patientdata), 10 patients total
    
    if isempty(patientdata(i).ECG) == 1
        continue
    end
    
    
    for j=1:4   % 4 classes
        
        % Declaration
        HRVsig = cell(1,1);
        CWTsig = cell(1,1);
        CWTavg = cell(1,1);
        
        ECG_low = filter(Blow,Alow,patientdata(i).ECG{j});
        HRVsig{j} = HRV(ECG_low);
           

        % CWT computation
        Fs_hrv = 1/(((length(patientdata(i).ECG{j})/400)/... 
                 length(HRVsig{j})));
        [CWTsig{j},CWTavg{j}] = CWTscalogram(HRVsig{j}(2,:),Fs_hrv,...
                 Fmin,Fmax,'HRV','off'); 
             
             
        % storage
        patientdata(i).HRV{j} = HRVsig{j};
        CWTdata(i).HRV.CWTsig{j} = CWTsig{j};
        CWTdata(i).HRV.CWTavg{j} = CWTavg{j};
    end
end



%% ABP

for i=1:10 %length(patientdata)
    
    if isempty(patientdata(i).ABP)
        continue
    end
    
    for j=1:4   % 4 classes
        
        % Declaration
        ABPsig = cell(1,1);
        CWTsig = cell(1,1);
        CWTavg = cell(1,1);
    
        ABPsig{j} = resample(patientdata(i).ABP{j},1,40);   % resample
   
        
        % CWT computation
        [CWTsig{j},CWTavg{j}] = CWTscalogram(ABPsig{j},10,...
                 Fmin,Fmax,'ABP','off'); 
    

        % storage
        patientdata(i).ABP{j} = ABPsig{j};
        CWTdata(i).ABP.CWTsig{j} = CWTsig{j};
        CWTdata(i).ABP.CWTavg{j} = CWTavg{j};
    end
end


%% LDF

% initialized to i=1, j=1, but if function deloutliers.m fails, re-run 
% section and script starts at correct increment 
i=1;
j=1;

%%
for i=i:length(patientdata) % total number of patients
    
    if isempty(patientdata(i).LDF)
        continue
    end
    
    for j=j:4
        
         % extract LDF
         LDFsig = cell(1,1);
         CWTsig = cell(1,1);
         CWTavg = cell(1,1);
         
         repeat = 1;
           
         while repeat == 1
             LDF_fs10 = resample(patientdata(i).LDF{j},1,40);
             close all
             plot(LDF_fs10/max(LDF_fs10))
             MinPP = input('MinPP value: ');
             LDFsig{j} = deloutliers(LDF_fs10,MinPP);
             hold on
             plot(LDFsig{j})
             repeat = input('Repeat? (Y=1,N=0) : ');
             hold off
         end
            
         % CWT computation
         [CWTsig{j},CWTavg{j}] = CWTscalogram(LDFsig{j},10,...
                Fmin,Fmax,'LDF','off'); 
            
         
         % storage
         patientdata(i).LDF2{j} = LDFsig{j};
         CWTdata(i).LDF.CWTsig{j} = CWTsig{j};
         CWTdata(i).LDF.CWTavg{j} = CWTavg{j};
        
         
         if j == 4
            j = 1;
         end
          
    end

    close
end

% save data
save('patientdata.mat','patientdata','-v7.3')
save('CWTdata.mat','CWTdata','-v7.3')



