% plotCWT Plot all CWT signals in 2-D and 3-D
%   Uses CWTdata struct with CWT data for all signals; 3 biomedical signals
%   at the four periods for 9 patients. For each of the 3 bio signals
%   plot all all periods for all patients together in 2-D and in
%   3-D by adding offset in one dimension.
%

% Created by Mathias Falk, last modified 19/08/16



col = cellstr(['r';'g';'c';'b']);
for i=2:3 % 3 signals
    
    figure(1+2*(i-1))
    figure(2+2*(i-1))
    
    z = 1:(9*4);
    c = 0;
  
    for j=1:10 % 10 patients
   
        for k=1:4 % 4 classes
                
            if j==4
                continue
            end
            
            if i == 1
                data = CWTdata(j).HRV; 
                comMaxLen = min(cellfun(@numel,data.CWTavg));
                data.CWTavg = cellfun(@(x) x(1:comMaxLen),...
                                      data.CWTavg,'UniformOutput',false);
                patientmax = cell2mat(data.CWTavg);
                patientmax = max(patientmax(:));
                str = 'Avg CWT for HRV';
            elseif i == 2
                data = CWTdata(j).ABP;
                comMaxLen = min(cellfun(@numel,data.CWTavg));
                data.CWTavg = cellfun(@(x) x(1:comMaxLen),...
                                      data.CWTavg,'UniformOutput',false);
                patientmax = cell2mat(data.CWTavg);
                patientmax = max(patientmax(:));
                str = 'Avg CWT for ABP';
            else
                data = CWTdata(j).LDF;
                comMaxLen = min(cellfun(@numel,data.CWTavg));
                data.CWTavg = cellfun(@(x) x(1:comMaxLen),...
                                      data.CWTavg,'UniformOutput',false);
                patientmax = cell2mat(data.CWTavg);
                patientmax = max(patientmax(:));
                str = 'Avg CWT for LDF';
            end
   
            figure(1+2*(i-1))
            semilogx(data.CWTsig{k}.frequencies(1:352),data.CWTavg{k}(1:352)/patientmax,col{k})
            hold on
            
            c = c + 1;
            figure(2+2*(i-1))
            plot3(repmat(z(c),352),data.CWTsig{k}.frequencies(1:352),data.CWTavg{k}(1:352)/patientmax,col{k});
            hold on
        
        end
    end
    
    figure(1+2*(i-1))
    h = zeros(4, 1);
    h(1) = plot(0,0,'r', 'visible', 'off');
    h(2) = plot(0,0,'g', 'visible', 'off');
    h(3) = plot(0,0,'c', 'visible', 'off');
    h(4) = plot(0,0,'b', 'visible', 'off');
    legend(h, 'A','B','C','D');
    
    title([str,' in 2D'])
    xlabel('Frequency [Hz]'); ylabel('Power [AU]')
    set(gca,'FontSize',14)
    axis('tight')
    
    figure(2+2*(i-1))
    h = zeros(4, 1);
    h(1) = plot(0,0,'r', 'visible', 'off');
    h(2) = plot(0,0,'g', 'visible', 'off');
    h(3) = plot(0,0,'c', 'visible', 'off');
    h(4) = plot(0,0,'b', 'visible', 'off');
    legend(h, 'A','B','C','D');
    
    title([str,' in 3D'])
    xlabel('Signal [number]'); ylabel('Frequency [Hz]'); zlabel('Power [AU]')
    set(gca,'FontSize',14)
    axis('tight')
    
    ax = gca;
    ax.YScale = 'log';
    ax.YDir = 'reverse';
    hold off
   
end

    
