function rffplotK(featureX,classY)
% rffplotK ReliefF analysis of K
%   rffplotK(featureX,classY) returns a plot of weights computed by ReliefF 
%   for each feature in the featureX input matrix, with corresponding 
%   classY class label string vector, for different K values in the nearest 
%   neighbor search of ReleifF. K is varied from 2 (1 could be unstable) to
%   85% of the size of observations of the features. The weights are 
%   plotted for each feature in the input.
%

%   Created by Mathias Falk, last modified 15/07/16

    weightsData = [];
    rankedData = [];

    x = [];
    for k=2:floor(0.85*length(classY))
        x = [x k];
        [ranked,weights] = relieff(featureX,classY,k);
        weightsData = [weightsData; weights];
        rankedData = [rankedData; ranked];
    end

    [~,clm] = size(featureX);
    figure
    for i=1:clm 
    plot(x,weightsData(:,i))
    hold on
    xlabel('Number of K nearest neighbors')
    ylabel('ReliefF weights')
    axis('tight')
    set(gca,'FontSize',16)
    end
end

