% siganalysis Signal analysis and plots
%   Using excerpts of signals form patient 02 and whole signals form 
%   other patients. Show ECG with and without noise, and corresponding CWT 
%   analysis. Show ECG with glitch artifact and corresponding HRV R peak 
%   detection, and CWT calculation. Show LDF with and without outlier 
%   detection and removal, and corresponding CWT. Show ABP scalogram and
%   average scalogram. Plot ECG, HRV, ABP and LDF.
%

%   Created by Mathias Falk, last modified 10/06/16


%% EXC2 and EXC3 from pasient 02 analysis, show low freq artifacts
figure;
plot(ECG_exc2*10^3)
xlabel('Time [samples]')
ylabel('Voltage [mV]')
axis tight
set(gca,'FontSize',14)
ax1 = gca;
axes('position',[0.18 0.65 0.1 0.1])
plot(ECG_exc2(1300:3600)*10^3)
title('Magnified excerpt')
axis tight


figure;
plot(ECG_exc3*10^3)
xlabel('Time [samples]')
ylabel('Voltage [mV]')
axis tight
set(gca,'FontSize',14)
ax2 = gca;
set(ax2,'Ylim',get(ax1,'Ylim'));
axes('position',[0.18 0.65 0.1 0.1])
plot(ECG_exc3(1300:3600)*10^3)
title('Magnified excerpt')
axis tight

ECG_exc2_r = resample(ECG_exc2,1,20);
ECG_exc3_r = resample(ECG_exc3,1,20);
Fs_new = Fs/20;
fmin = 0.005;
fmax = 1.5;
plotting = '2';

CWTscalogram(ECG_exc2_r,Fs_new,fmin,fmax,...
    'of ECG with noise artifact',plotting);
set(gca,'FontSize',14)

CWTscalogram(ECG_exc3_r,Fs_new,fmin,fmax,...
     'of ECG with noise artifact',plotting);
set(gca,'FontSize',14)


%% ECG severe noise and HRV detection
ECG_exc4_2 = ECG_exc5_low(100:end); %ECG_exc2(2*1e4:5*1e4);
figure;
%t = linspace(0,length(ECG_exc4)/400,length(ECG_exc4));
plot((ECG_exc4_2-mean(ECG_exc4_2))*10^3)
title('Time series ECG with severe movement artifacts')
xlabel('Time [samples]')
ylabel('Voltage [mV]')
axis('tight')

[HRVsig, HRVinfo] = HRV(ECG_exc4_2*10^3);
hold on
plot(HRVinfo(1,:),HRVinfo(2,:),'v')
hold off 
set(gca,'FontSize',14)

% CWT computation
Fs_hrv = 1/(((length(ECG_exc4_2)/400)/length(HRVsig)));
CWTscalogram(HRVsig(2,:),Fs_hrv,fmin,fmax,...
    'of HRV from ECG with severe noise','2');
set(gca,'FontSize',14)



%% EXC4 glitch artifact, and HRV peak detection
ECG_exc4_2 = ECG_exc4(2.1*10^4:3.9*10^4);
figure;
%t = linspace(0,length(ECG_exc4)/400,length(ECG_exc4));
plot((ECG_exc4_2-mean(ECG_exc4_2))*10^3)
title('Time series ECG with glitch artifact')
xlabel('Time [samples]')
ylabel('Voltage [mV]')
axis('tight')

[HRVsig, HRVinfo] = HRV(ECG_exc4_2*10^3);
hold on
plot(HRVinfo(1,:),HRVinfo(2,:),'v')
hold off 
set(gca,'FontSize',14)

% CWT computation
Fs_hrv = 1/(((length(ECG_exc4_2)/400)/length(HRVsig)));
CWTscalogram(HRVsig(2,:),Fs_hrv,fmin,fmax,...
    'of HRV from ECG with noise artifact','2');
set(gca,'FontSize',14)




%% LDF avg scalogram pre and post outliers removal
Fs_LDF = 400/40;
LDF_exc3 = {resample(patientdata(1).LDF{2},1,Fs_LDF);
            resample(patientdata(9).LDF{1},1,Fs_LDF)};

for i=1:2
    LDF_exc33 = LDF_exc3{i};
    figure;
    plot(LDF_exc33/max(LDF_exc33))
    title('LDF signal')
    xlabel('Time [samples]')
    ylabel('Voltage [AU]')

    LDF_exc2_od = deloutliers(LDF_exc33,0.2);
    hold on
    plot(LDF_exc2_od)
    set(gca,'FontSize',14)
    hold off
    legend('LDF with outlier','LDF with outlier erased')
    
    % CWT
    [CWTsig1,CWTavg1] = CWTscalogram(LDF_exc33/max(LDF_exc33),...
                        Fs_LDF,fmin,fmax,'LDF with outliers','off');
    [CWTsig2,CWTavg2] = CWTscalogram(LDF_exc2_od,Fs_LDF,fmin,fmax,...
                        'LDF','off');

    figure
    semilogx(CWTsig1.frequencies,CWTavg1)
    hold on
    semilogx(CWTsig2.frequencies,CWTavg2)
    xlabel('Frequency [Hz]'); ylabel('Power [AU]')
    title('Average CWT of LDF signal')
    set(gca,'FontSize',14)
    hold off
    legend('LDF with outlier','LDF with outlier erased')
end


%% ABP scalogram vs average
ABP_exc = resample(patientdata(5).ABP{1},1,80);
CWTscalogram(ABP_exc,5,fmin,2,'ABP','1');



%% Time series plot 

% LDF
figure
plot(patientdata(1).LDF{2}*1e3)
xlabel('Time [samples]'); ylabel('Voltage [mV]')
set(gca,'FontSize',14)

% ABP
figure
plot(patientdata(1).ABP{2}(2.3*1e5:2.35*1e5))
axis('tight')
xlabel('Time [samples]'); ylabel('Pressure [mmHg]')
set(gca,'FontSize',14)

% HRV
figure
plot(patientdata(1).HRV{1}(1,:),patientdata(1).HRV{1}(2,:))
xlabel('Time [samples]'); ylabel('RR interval [samples]')
set(gca,'FontSize',14)

% ECG
figure
ECG_filter = filter(Blow,Alow,patientdata(1).ECG{2});
plot(ECG_filter(3.095*1e5:3.126*1e5)*1e3)
axis('tight')
xlabel('Time [samples]'); ylabel('Voltage [mV]')
set(gca,'FontSize',14)




