% wavanalysis Wavelet Analysis
%   Compute the Mexican hat and Morlet wavelets and plot, then find the 
%   Fourier transform (using FFT) of the wavelets.
%

%   Created by Mathias Falk, last modified 15/08/16


fs = 1000;                       % Samling rate
lb = -4;                         % Lower bound
ub = 4;                          % Upper bound
fb = 5/(2*pi);                   % freq width/bound
fc = 5/(2*pi);                   % freq center
t = linspace(lb,ub,(ub-lb)*fs ); % time vector, effective support



% Compute values of the Mexican hat wavelet.
psi1 = t.^2;
psi1 = (2/(sqrt(3)*pi^fc)) * exp(-psi1/2) .* (1-psi1);
figure;
plot(t,psi1)
title('Mexican hat'); xlabel('Time [s]')
set(gca,'FontSize',14)


% Compute values of the Complex Morlet wavelet.
psi2 = ((pi*fb)^(-0.5))*exp(2*1i*pi*fc*t).*exp(-(t.*t)/fb);
figure;
plot(x,real(psi2));
hold on; plot(x,imag(psi2))
legend('Real part','Imaginary part')
title('Morlet'); xlabel('Time [s]')
set(gca,'FontSize',14)


% FFT plot
psi = [psi1;psi2];
xlimit = [-1 1;-1 3];
Nfft =10*2^nextpow2(length(t));
for i=1:2
    
    fft2 =fftshift(abs(fft(psi(i,:),Nfft)));
    f=(0:Nfft - 1).*(fs/Nfft);
    f(f >= fs/2) = f(f >= fs/2) - fs;
    f=fftshift(f);
    figure
    plot(f, fft2); 
    xlim(xlimit(i,:));
    xlabel('Frequency [Hz]');
    title('Fourier Transform');
    set(gca,'FontSize',14)
end

